@@ -6,7 +6,7 @@ from dateutil import parser
 import re
 from knack.util import CLIError
 from knack.log import get_logger
-from msrestazure.tools import parse_resource_id, resource_id, is_valid_resource_id, is_valid_resource_name
+from azure.mgmt.core.tools import parse_resource_id, resource_id, is_valid_resource_id, is_valid_resource_name
 from azure.cli.core.azclierror import ValidationError, ArgumentUsageError, InvalidArgumentValueError
 from azure.cli.core.commands.client_factory import get_mgmt_service_client, get_subscription_id
 from azure.cli.core.util import parse_proxy_resource_id
@@ -105,10 +105,10 @@ def mysql_restore_tier_validator(target_tier, source_tier, sku_info):
 def mysql_arguments_validator(db_context, location, tier, sku_name, storage_gb, backup_retention=None, server_name=None,
                               zone=None, standby_availability_zone=None, high_availability=None, backup_byok_key=None,
                               public_access=None, version=None, auto_grow=None, replication_role=None, subnet=None,
-                              byok_identity=None, backup_byok_identity=None, byok_key=None, geo_redundant_backup=None,
-                              disable_data_encryption=None, iops=None, auto_io_scaling=None, instance=None,
-                              data_source_type=None, mode=None,
-                              data_source_backup_dir=None, data_source_sas_token=None):
+                              byok_identity=None, backup_interval=None, backup_byok_identity=None, byok_key=None,
+                              geo_redundant_backup=None, disable_data_encryption=None, iops=None, auto_io_scaling=None,
+                              accelerated_logs=None, instance=None, data_source_type=None,
+                              mode=None, data_source_backup_dir=None, data_source_sas_token=None):
     validate_server_name(db_context, server_name, 'Microsoft.DBforMySQL/flexibleServers')
 
     list_skus_info = get_mysql_list_skus_info(db_context.cmd, location, server_name=instance.name if instance else None)
@@ -132,7 +132,9 @@ def mysql_arguments_validator(db_context, location, tier, sku_name, storage_gb,
     mysql_auto_grow_validator(auto_grow, replication_role, high_availability, instance)
     _mysql_byok_validator(byok_identity, backup_byok_identity, byok_key, backup_byok_key,
                           disable_data_encryption, geo_redundant_backup, instance)
+    _mysql_backup_interval_validator(backup_interval)
     _mysql_iops_validator(iops, auto_io_scaling, instance)
+    mysql_accelerated_logs_validator(accelerated_logs, tier)
     _mysql_import_data_source_type_validator(data_source_type, data_source_backup_dir, data_source_sas_token)
     _mysql_import_mode_validator(mode)
 
@@ -300,6 +302,13 @@ def _mysql_byok_validator(byok_identity, backup_byok_identity, byok_key, backup_
                        "Use the primary server instead.")
 
 
+def _mysql_backup_interval_validator(backup_interval):
+    if backup_interval is None:
+        return
+    if backup_interval not in [6, 12, 24]:
+        raise ArgumentUsageError("Incorrect value for --backup-interval. Allowed values: [6, 12, 24]")
+
+
 def _mysql_iops_validator(iops, auto_io_scaling, instance):
     if iops is None:
         return
@@ -309,6 +318,12 @@ def _mysql_iops_validator(iops, auto_io_scaling, instance):
         logger.warning("The server has enabled the auto scale iops. So the iops will be ignored.")
 
 
+def mysql_accelerated_logs_validator(accelerated_logs, tier):
+    if tier != "MemoryOptimized" and accelerated_logs is not None and accelerated_logs.lower() == "enabled":
+        logger.warning("Accelerated logs is only supported for Memory Optimized tier. "
+                       "So the accelerated logs will be disabled.")
+
+
 def _network_arg_validator(subnet, public_access):
     if subnet is not None and public_access is not None:
         raise CLIError("Incorrect usage : A combination of the parameters --subnet "
@@ -553,3 +568,11 @@ def validate_action_name(namespace):
 def validate_branch(namespace):
     if not re.search(r'^[-_a-zA-Z0-9]+$', namespace.branch):
         raise ValidationError("The branch can only contain 0-9, a-z, A-Z, \'-\' and \'_\'.")
+
+
+def validate_and_format_maintenance_start_time(maintenance_start_time):
+    try:
+        return parser.parse(maintenance_start_time)
+    except:
+        raise ValidationError("The maintenance_start_time value has incorrect date format. "
+                              "Please use ISO format e.g., 2024-06-01T00:08:23+00:00")
