@@ -15,11 +15,10 @@ from azure.cli.core.commands import CliCommandType, DeploymentOutputLongRunningO
 from azure.cli.core.commands.arm import handle_template_based_exception
 from azure.cli.command_modules.resource._client_factory import (
     cf_resource_groups, cf_providers, cf_features, cf_feature_registrations, cf_tags, cf_deployments,
-    cf_deployment_operations, cf_policy_definitions, cf_policy_set_definitions, cf_policy_exemptions, cf_resource_links, cf_resource_deploymentstacks,
+    cf_deployment_operations, cf_resource_links, cf_resource_deploymentstacks,
     cf_resource_deploymentscripts, cf_resource_managedapplications, cf_resource_managedappdefinitions, cf_management_groups, cf_management_groups_mixin, cf_management_group_subscriptions, cf_management_group_entities, cf_hierarchy_settings, cf_resource_templatespecs, cf_resource_resourcemanagementprivatelinks, cf_resource_privatelinkassociations)
 from azure.cli.command_modules.resource._validators import (
-    process_deployment_create_namespace, process_ts_create_or_update_namespace, _validate_template_spec, _validate_template_spec_out,
-    process_assign_identity_namespace, process_assignment_create_namespace, validate_deployment_stack_files)
+    process_deployment_create_namespace, process_ts_create_or_update_namespace, _validate_template_spec, _validate_template_spec_out, validate_deployment_stack_files)
 
 from ._exception_handler import managementgroups_exception_handler
 
@@ -169,23 +168,51 @@ def load_command_table(self, _):
         resource_type=ResourceType.MGMT_RESOURCE_DEPLOYMENTS
     )
 
-    resource_policy_definitions_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.resource.policy.operations#PolicyDefinitionsOperations.{}',
-        client_factory=cf_policy_definitions,
-        resource_type=ResourceType.MGMT_RESOURCE_POLICY
-    )
+    with self.command_group('policy assignment'):
+        from .policy import PolicyAssignmentCreate, PolicyAssignmentDelete, PolicyAssignmentList, PolicyAssignmentShow, PolicyAssignmentUpdate
+        self.command_table['policy assignment create'] = PolicyAssignmentCreate(loader=self)
+        self.command_table['policy assignment delete'] = PolicyAssignmentDelete(loader=self)
+        self.command_table['policy assignment list'] = PolicyAssignmentList(loader=self)
+        self.command_table['policy assignment show'] = PolicyAssignmentShow(loader=self)
+        self.command_table['policy assignment update'] = PolicyAssignmentUpdate(loader=self)
 
-    resource_policy_set_definitions_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.resource.policy.operations#PolicySetDefinitionsOperations.{}',
-        client_factory=cf_policy_set_definitions,
-        resource_type=ResourceType.MGMT_RESOURCE_POLICY
-    )
+    with self.command_group('policy assignment identity'):
+        from .policy import PolicyAssignmentIdentityAssign, PolicyAssignmentIdentityRemove, PolicyAssignmentIdentityShow
+        self.command_table['policy assignment identity assign'] = PolicyAssignmentIdentityAssign(loader=self)
+        self.command_table['policy assignment identity remove'] = PolicyAssignmentIdentityRemove(loader=self)
+        self.command_table['policy assignment identity show'] = PolicyAssignmentIdentityShow(loader=self)
 
-    resource_policy_exemptions_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.resource.policy.operations#PolicyExemptionsOperations.{}',
-        client_factory=cf_policy_exemptions,
-        resource_type=ResourceType.MGMT_RESOURCE_POLICY
-    )
+    with self.command_group('policy assignment non-compliance-message'):
+        from .policy import PolicyAssignmentNonComplianceMessageCreate, PolicyAssignmentNonComplianceMessageDelete, PolicyAssignmentNonComplianceMessageList, PolicyAssignmentNonComplianceMessageShow, PolicyAssignmentNonComplianceMessageUpdate
+        self.command_table['policy assignment non-compliance-message create'] = PolicyAssignmentNonComplianceMessageCreate(loader=self)
+        self.command_table['policy assignment non-compliance-message delete'] = PolicyAssignmentNonComplianceMessageDelete(loader=self)
+        self.command_table['policy assignment non-compliance-message list'] = PolicyAssignmentNonComplianceMessageList(loader=self)
+        self.command_table['policy assignment non-compliance-message show'] = PolicyAssignmentNonComplianceMessageShow(loader=self)
+        self.command_table['policy assignment non-compliance-message update'] = PolicyAssignmentNonComplianceMessageUpdate(loader=self)
+
+    with self.command_group('policy definition'):
+        from .policy import PolicyDefinitionCreate, PolicyDefinitionDelete, PolicyDefinitionList, PolicyDefinitionShow, PolicyDefinitionUpdate
+        self.command_table['policy definition create'] = PolicyDefinitionCreate(loader=self)
+        self.command_table['policy definition delete'] = PolicyDefinitionDelete(loader=self)
+        self.command_table['policy definition list'] = PolicyDefinitionList(loader=self)
+        self.command_table['policy definition show'] = PolicyDefinitionShow(loader=self)
+        self.command_table['policy definition update'] = PolicyDefinitionUpdate(loader=self)
+
+    with self.command_group('policy exemption'):
+        from .policy import PolicyExemptionCreate, PolicyExemptionDelete, PolicyExemptionList, PolicyExemptionShow, PolicyExemptionUpdate
+        self.command_table['policy exemption create'] = PolicyExemptionCreate(loader=self)
+        self.command_table['policy exemption delete'] = PolicyExemptionDelete(loader=self)
+        self.command_table['policy exemption list'] = PolicyExemptionList(loader=self)
+        self.command_table['policy exemption show'] = PolicyExemptionShow(loader=self)
+        self.command_table['policy exemption update'] = PolicyExemptionUpdate(loader=self)
+
+    with self.command_group('policy set-definition'):
+        from .policy import PolicySetDefinitionCreate, PolicySetDefinitionDelete, PolicySetDefinitionList, PolicySetDefinitionShow, PolicySetDefinitionUpdate
+        self.command_table['policy set-definition create'] = PolicySetDefinitionCreate(loader=self)
+        self.command_table['policy set-definition delete'] = PolicySetDefinitionDelete(loader=self)
+        self.command_table['policy set-definition list'] = PolicySetDefinitionList(loader=self)
+        self.command_table['policy set-definition show'] = PolicySetDefinitionShow(loader=self)
+        self.command_table['policy set-definition update'] = PolicySetDefinitionUpdate(loader=self)
 
     resource_lock_sdk = CliCommandType(
         operations_tmpl='azure.mgmt.resource.locks.operations#ManagementLocksOperations.{}',
@@ -496,54 +523,6 @@ def load_command_table(self, _):
         g.custom_command('list', 'list_deployment_operations_at_tenant_scope')
         g.custom_show_command('show', 'get_deployment_operations_at_tenant_scope', client_factory=cf_deployment_operations)
 
-    # Since "MGMT_RESOURCE_POLICY" is not the default resource type used by the __init__ method
-    # in ResourceCommandsLoader, so the default "operation_group" cannot be specified in the commandsLoader,
-    # the "operation_group" needs to be explicitly specified for "MGMT_RESOURCE_POLICY".
-
-    with self.command_group('policy assignment',
-                            operation_group='policy_assignments', resource_type=ResourceType.MGMT_RESOURCE_POLICY) as g:
-        g.custom_command('create', 'create_policy_assignment', validator=process_assignment_create_namespace)
-        g.custom_command('delete', 'delete_policy_assignment')
-        g.custom_command('list', 'list_policy_assignment')
-        g.custom_show_command('show', 'show_policy_assignment')
-        g.custom_command('update', 'update_policy_assignment')
-
-    with self.command_group('policy assignment identity',
-                            operation_group='policy_assignments', resource_type=ResourceType.MGMT_RESOURCE_POLICY, min_api='2018-05-01') as g:
-        g.custom_command('assign', 'set_identity', validator=process_assign_identity_namespace, min_api='2021-06-01')
-        g.custom_show_command('show', 'show_identity')
-        g.custom_command('remove', 'remove_identity')
-
-    with self.command_group('policy assignment non-compliance-message',
-                            operation_group='policy_assignments', resource_type=ResourceType.MGMT_RESOURCE_POLICY, min_api='2020-09-01') as g:
-        g.custom_command('create', 'create_policy_non_compliance_message')
-        g.custom_command('list', 'list_policy_non_compliance_message')
-        g.custom_command('delete', 'delete_policy_non_compliance_message')
-
-    with self.command_group('policy definition', resource_policy_definitions_sdk,
-                            operation_group='policy_definitions', resource_type=ResourceType.MGMT_RESOURCE_POLICY) as g:
-        g.custom_command('create', 'create_policy_definition')
-        g.custom_command('delete', 'delete_policy_definition')
-        g.custom_command('list', 'list_policy_definition')
-        g.custom_show_command('show', 'get_policy_definition')
-        g.custom_command('update', 'update_policy_definition')
-
-    with self.command_group('policy set-definition', resource_policy_set_definitions_sdk,
-                            operation_group='policy_set_definitions', resource_type=ResourceType.MGMT_RESOURCE_POLICY, min_api='2017-06-01-preview') as g:
-        g.custom_command('create', 'create_policy_setdefinition')
-        g.custom_command('delete', 'delete_policy_setdefinition')
-        g.custom_command('list', 'list_policy_setdefinition')
-        g.custom_show_command('show', 'get_policy_setdefinition')
-        g.custom_command('update', 'update_policy_setdefinition')
-
-    with self.command_group('policy exemption', resource_policy_exemptions_sdk, is_preview=True,
-                            operation_group='policy_exemptions', resource_type=ResourceType.MGMT_RESOURCE_POLICY, min_api='2020-07-01-preview') as g:
-        g.custom_command('create', 'create_policy_exemption')
-        g.custom_command('delete', 'delete_policy_exemption')
-        g.custom_command('list', 'list_policy_exemption')
-        g.custom_show_command('show', 'get_policy_exemption')
-        g.custom_command('update', 'update_policy_exemption')
-
     with self.command_group('lock', resource_type=ResourceType.MGMT_RESOURCE_LOCKS) as g:
         g.custom_command('create', 'create_lock')
         g.custom_command('delete', 'delete_lock')
