@@ -69,22 +69,19 @@ def create_container_rm(cmd, client, container_name, resource_group_name, accoun
                                              account_name=account_name, container_name=container_name):
         raise CLIError('The specified container already exists.')
 
-    if cmd.supported_api_version(min_api='2019-06-01', resource_type=ResourceType.MGMT_STORAGE):
-        BlobContainer = cmd.get_models('BlobContainer', resource_type=ResourceType.MGMT_STORAGE)
-        blob_container = BlobContainer(public_access=public_access,
-                                       default_encryption_scope=default_encryption_scope,
-                                       deny_encryption_scope_override=deny_encryption_scope_override,
-                                       metadata=metadata,
-                                       enable_nfs_v3_all_squash=enable_nfs_v3_all_squash,
-                                       enable_nfs_v3_root_squash=enable_nfs_v3_root_squash)
-        if enable_vlw is not None:
-            ImmutableStorageWithVersioning = cmd.get_models('ImmutableStorageWithVersioning',
-                                                            resource_type=ResourceType.MGMT_STORAGE)
-            blob_container.immutable_storage_with_versioning = ImmutableStorageWithVersioning(enabled=enable_vlw)
-        return client.create(resource_group_name=resource_group_name, account_name=account_name,
-                             container_name=container_name, blob_container=blob_container)
+    BlobContainer = cmd.get_models('BlobContainer', resource_type=ResourceType.MGMT_STORAGE)
+    blob_container = BlobContainer(public_access=public_access,
+                                   default_encryption_scope=default_encryption_scope,
+                                   deny_encryption_scope_override=deny_encryption_scope_override,
+                                   metadata=metadata,
+                                   enable_nfs_v3_all_squash=enable_nfs_v3_all_squash,
+                                   enable_nfs_v3_root_squash=enable_nfs_v3_root_squash)
+    if enable_vlw is not None:
+        ImmutableStorageWithVersioning = cmd.get_models('ImmutableStorageWithVersioning',
+                                                        resource_type=ResourceType.MGMT_STORAGE)
+        blob_container.immutable_storage_with_versioning = ImmutableStorageWithVersioning(enabled=enable_vlw)
     return client.create(resource_group_name=resource_group_name, account_name=account_name,
-                         container_name=container_name, public_access=public_access, metadata=metadata)
+                         container_name=container_name, blob_container=blob_container)
 
 
 def update_container_rm(cmd, instance, metadata=None, public_access=None,
@@ -329,12 +326,15 @@ def set_service_properties_track2(client, parameters, delete_retention=None, del
 
     if hasattr(parameters, 'static_website'):
         kwargs['static_website'] = parameters.static_website
-    if static_website is not None:
-        parameters.static_website.enabled = static_website
     if index_document is not None:
         parameters.static_website.index_document = index_document
     if error_document_404_path is not None:
         parameters.static_website.error_document404_path = error_document_404_path
+    if static_website is not None:
+        parameters.static_website.enabled = static_website
+        if not static_website:
+            parameters.static_website.index_document = None
+            parameters.static_website.error_document404_path = None
     if hasattr(parameters, 'hour_metrics'):
         kwargs['hour_metrics'] = parameters.hour_metrics
     if hasattr(parameters, 'logging'):
@@ -899,7 +899,7 @@ def create_blob_url(client, container_name, blob_name, snapshot, protocol='https
         url = blob_client.url
     else:
         container_client = client.get_container_client(container=container_name)
-        url = container_client.url + '/'
+        url = container_client.url if '?' in container_client.url else container_client.url + '/'
     if protocol == 'http':
         return url.replace('https', 'http', 1)
     return url
@@ -908,6 +908,14 @@ def create_blob_url(client, container_name, blob_name, snapshot, protocol='https
 def _copy_blob_to_blob_container(cmd, blob_service, source_blob_service, destination_container, destination_path,
                                  source_container, source_blob_name, source_sas, **kwargs):
     t_blob_client = cmd.get_models('_blob_client#BlobClient')
+    # generate sas for oauth copy source
+    if not source_sas:
+        from ..util import create_short_lived_blob_sas_v2
+        start = datetime.utcnow()
+        expiry = datetime.utcnow() + timedelta(hours=1)
+        source_user_delegation_key = source_blob_service.get_user_delegation_key(start, expiry)
+        source_sas = create_short_lived_blob_sas_v2(cmd, source_blob_service.account_name, source_container,
+                                                    source_blob_name, user_delegation_key=source_user_delegation_key)
     source_client = t_blob_client(account_url=source_blob_service.url, container_name=source_container,
                                   blob_name=source_blob_name, credential=source_sas)
     source_blob_url = source_client.url
@@ -931,7 +939,10 @@ def _copy_file_to_blob_container(blob_service, source_file_service, destination_
                                  source_share, source_sas, source_file_dir, source_file_name):
     t_share_client = source_file_service.get_share_client(source_share)
     t_file_client = t_share_client.get_file_client(os.path.join(source_file_dir, source_file_name))
-    source_file_url = '{}?{}'.format(t_file_client.url, source_sas)
+    if '?' not in t_file_client.url:
+        source_file_url = '{}?{}'.format(t_file_client.url, source_sas)
+    else:
+        source_file_url = t_file_client.url
 
     source_path = os.path.join(source_file_dir, source_file_name) if source_file_dir else source_file_name
     destination_blob_name = normalize_blob_file_path(destination_path, source_path)
@@ -1078,3 +1089,40 @@ def exists(client, container_name, blob_name, snapshot, timeout):
     else:
         client = client.get_container_client(container=container_name)
     return client.exists(timeout=timeout)
+
+
+def incremental_copy_start(client, cmd, copy_source=None, metadata=None,
+                           destination_if_modified_since=None, destination_if_unmodified_since=None,
+                           destination_if_match=None, destination_if_none_match=None, **kwargs):
+    from ..aaz.latest.storage.blob.incremental_copy import Start
+
+    cmd_args = {
+        "x_ms_version": "2025-07-05",
+        "account_name": client.account_name,
+        "destination_blob": client.blob_name,
+        "destination_container": client.container_name,
+        "source_uri": copy_source,
+        "comp": 'incrementalcopy',
+        "destination_if_modified_since": destination_if_modified_since,
+        "destination_if_unmodified_since": destination_if_unmodified_since,
+        "destination_if_match": destination_if_match,
+        "destination_if_none_match": destination_if_none_match,
+    }
+    _Start = Start(cli_ctx=cmd.cli_ctx)
+
+    def on_202(self, session):
+        result = dict(session.http_response.headers._store)
+        output = {
+            "completionTime": None,
+            "id": result.get('x-ms-copy-id')[1],
+            "progress": None,
+            "source": None,
+            "status": result.get('x-ms-copy-status')[1],
+            "statusDescription": None
+        }
+        self.ctx.vars._output = output
+
+    _Start.PageBlobCopyIncremental.on_202 = on_202
+
+    _Start(command_args=cmd_args)
+    return _Start.ctx.vars._output
